@@ -39,6 +39,8 @@ B_AB = Gaia_DR2.phot_bp_mean_mag - 25.351 + 25.386
 R_AB = Gaia_DR2.phot_rp_mean_mag - 24.762 + 25.116
 B_AB_R_AB = B_AB - R_AB
 
+colour_absg = ((absg > 4.09) | (absg > 4.5457 * bp_rp + 4.0457))
+
 pmra = Gaia_DR2.pmra
 pmdec = Gaia_DR2.pmdec
 pmra_error = Gaia_DR2.pmra_error
@@ -98,6 +100,7 @@ class MWM_CB_UVEX1_Carton(BaseCarton):
         - Colour and magnitude cuts:
             - nuv_magerr < 0.2 && nuv_mag>-100 &&
                 (fuv_magerr >=0.2 || fuv_mag< -100)
+            - absg < (absg > 4.09 || absg > 4.5457*bp_rp + 4.0457)  [colour_abs]
             - ((nuv_mag-gmagab) < 2.25 ||
                 ((nuv_mag-gmagab) < 6.725*(B_AB-R_AB)-1.735  &&
                  (nuv_mag-gmagab)< -0.983*(B_AB-R_AB)+8.24))
@@ -130,6 +133,7 @@ class MWM_CB_UVEX1_Carton(BaseCarton):
                        nuv_magerr < 0.2,
                        fuv_mag > -100,
                        nuv_mag > -100,
+                       colour_absg,
                        (absg > -1.11749253e-03 * fn.pow(fuv_nuv, 3) +
                         1.53748615e-02 * fn.pow(fuv_nuv, 2) +
                         3.66419895e-01 * fuv_nuv + 2.20026639),
@@ -139,6 +143,8 @@ class MWM_CB_UVEX1_Carton(BaseCarton):
         query = (GUVCat
                  .select(CatalogToTIC_v8.catalogid,
                          Gaia_DR2.source_id,
+                         Gaia_DR2.ra.alias('gaia_ra'),
+                         Gaia_DR2.dec.alias('gaia_dec'),
                          Gaia_DR2.pmra,
                          Gaia_DR2.pmdec,
                          Gaia_DR2.pmra_error,
@@ -150,6 +156,9 @@ class MWM_CB_UVEX1_Carton(BaseCarton):
                          Gaia_DR2.phot_rp_mean_mag,
                          BJ.r_est,
                          BJ.r_lo,
+                         GUVCat.objid.alias('guvcat_objid'),
+                         GUVCat.ra.alias('guvcat_ra'),
+                         GUVCat.dec.alias('guvcat_dec'),
                          GUVCat.nuv_mag,
                          GUVCat.fuv_mag,
                          GUVCat.nuv_magerr,
@@ -219,6 +228,7 @@ class MWM_CB_UVEX2_Carton(BaseCarton):
         - Colour and magnitude cuts:
             - fuv_magerr < 0.2 && nuv_magerr < 0.2 &&
               fuv_mag > -100 && nuv_mag > -100
+            - absg < (absg > 4.09 || absg > 4.5457*bp_rp + 4.0457)  [colour_abs]
             - absg > -1.11749253e-03*fuv_nuv^3 +
                 1.53748615e-02*fuv_nuv^2 +
                 3.66419895e-01*fuv_nuv+2.20026639e+00
@@ -251,6 +261,7 @@ class MWM_CB_UVEX2_Carton(BaseCarton):
 
         colour_cuts = (nuv_magerr < 0.2,
                        nuv_mag > -100,
+                       colour_absg,
                        (((nuv_mag - gmagab) < 2.25) |
                         (((nuv_mag - gmagab) < 6.725 * B_AB_R_AB - 1.735) &
                          ((nuv_mag - gmagab) < -0.983 * B_AB_R_AB + 8.24))))
@@ -258,6 +269,8 @@ class MWM_CB_UVEX2_Carton(BaseCarton):
         query = (GUVCat
                  .select(CatalogToGUVCat.catalogid,
                          Gaia_DR2.source_id,
+                         Gaia_DR2.ra.alias('gaia_ra'),
+                         Gaia_DR2.dec.alias('gaia_dec'),
                          Gaia_DR2.pmra,
                          Gaia_DR2.pmdec,
                          Gaia_DR2.pmra_error,
@@ -269,6 +282,9 @@ class MWM_CB_UVEX2_Carton(BaseCarton):
                          Gaia_DR2.phot_rp_mean_mag,
                          BJ.r_est,
                          BJ.r_lo,
+                         GUVCat.objid.alias('guvcat_objid'),
+                         GUVCat.ra.alias('guvcat_ra'),
+                         GUVCat.dec.alias('guvcat_dec'),
                          GUVCat.nuv_mag,
                          GUVCat.nuv_magerr)
                  .join(CatalogToGUVCat)
@@ -361,6 +377,7 @@ class MWM_CB_UVEX3_Carton(BaseCarton):
             - Gaia: visibility_periods_used >5
 
         - Colour and magnitude cuts:
+            - absg < (absg > 4.09 || absg > 4.5457*bp_rp + 4.0457)  [colour_abs]
             - ((UVM2_AB_MAG - gmagab) < 2.25 ||
                ((UVM2_AB_MAG - gmagab) < 6 &&
                 (UVM2_AB_MAG - gmagab) < 5.57377*(B_AB-R_AB)+0.2049))
@@ -427,13 +444,16 @@ class MWM_CB_UVEX3_Carton(BaseCarton):
                        .where(*quality_flags)
                        .cte('quality_cte', materialized=True))
 
-        colour_cuts = (((quality_cte.c.uvm2_ab_mag - gmagab) < 2.25) |
+        colour_cuts = (colour_absg,
+                       ((quality_cte.c.uvm2_ab_mag - gmagab) < 2.25) |
                        (((quality_cte.c.uvm2_ab_mag - gmagab) < 6) &
                         ((quality_cte.c.uvm2_ab_mag - gmagab) < 5.57377 * (B_AB_R_AB) + 0.2049)))
 
         query = (Catalog
                  .select(Catalog.catalogid,
                          Gaia_DR2.source_id,
+                         Gaia_DR2.ra.alias('gaia_ra'),
+                         Gaia_DR2.dec.alias('gaia_dec'),
                          Gaia_DR2.pmra,
                          Gaia_DR2.pmdec,
                          Gaia_DR2.pmra_error,
@@ -446,6 +466,7 @@ class MWM_CB_UVEX3_Carton(BaseCarton):
                          gmagab.alias('gmagab'),
                          BJ.r_est,
                          BJ.r_lo,
+                         XMM_OM_SUSS_4_1.srcnum,
                          quality_cte.c.uvm2_ab_mag.alias('uvm2_ab_mag'),
                          quality_cte.c.uvw2_ab_mag.alias('uvw2_ab_mag'),
                          quality_cte.c.uvw1_ab_mag.alias('uvw1_ab_mag'),
@@ -461,7 +482,7 @@ class MWM_CB_UVEX3_Carton(BaseCarton):
                  .where(CatalogToTIC_v8.version_id == version_id,
                         CatalogToTIC_v8.best >> True)
                  .where(Gaia_DR2.visibility_periods_used > 5)
-                 .where(colour_cuts)
+                 .where(*colour_cuts)
                  .where(*astrometric_cuts)
                  .with_cte(quality_cte))
 
@@ -531,6 +552,7 @@ class MWM_CB_UVEX4_Carton(BaseCarton):
             - Gaia: visibility_periods_used >5
 
         - Colour and magnitude cuts:
+            - absg < (absg > 4.09 || absg > 4.5457*bp_rp + 4.0457)  [colour_abs]
             - ((UVM2_AB_MAG - gmagab) < 2.25 ||
                ((UVM2_AB_MAG - gmagab) < 6 &&
                 (UVM2_AB_MAG - gmagab) < 5.57377*(B_AB-R_AB)+0.2049))
@@ -597,13 +619,16 @@ class MWM_CB_UVEX4_Carton(BaseCarton):
                        .where(*quality_flags)
                        .cte('quality_cte', materialized=True))
 
-        colour_cuts = (((quality_cte.c.uvm2_ab - gmagab) < 2.25) |
+        colour_cuts = (colour_absg,
+                       ((quality_cte.c.uvm2_ab - gmagab) < 2.25) |
                        (((quality_cte.c.uvm2_ab - gmagab) < 6) &
                         ((quality_cte.c.uvm2_ab - gmagab) < 5.57377 * (B_AB_R_AB) + 0.2049)))
 
         query = (Catalog
                  .select(Catalog.catalogid,
                          Gaia_DR2.source_id,
+                         Gaia_DR2.ra.alias('gaia_ra'),
+                         Gaia_DR2.dec.alias('gaia_dec'),
                          Gaia_DR2.pmra,
                          Gaia_DR2.pmdec,
                          Gaia_DR2.pmra_error,
@@ -616,6 +641,7 @@ class MWM_CB_UVEX4_Carton(BaseCarton):
                          gmagab.alias('gmagab'),
                          BJ.r_est,
                          BJ.r_lo,
+                         UVOT_SSC_1.srcnum,
                          quality_cte.c.uvm2_ab.alias('uvm2_ab'),
                          quality_cte.c.uvw2_ab.alias('uvw2_ab'),
                          quality_cte.c.uvw1_ab.alias('uvw1_ab'),
@@ -631,7 +657,7 @@ class MWM_CB_UVEX4_Carton(BaseCarton):
                  .where(CatalogToTIC_v8.version_id == version_id,
                         CatalogToTIC_v8.best >> True)
                  .where(Gaia_DR2.visibility_periods_used > 5)
-                 .where(colour_cuts)
+                 .where(*colour_cuts)
                  .where(*astrometric_cuts)
                  .with_cte(quality_cte))
 
@@ -728,6 +754,8 @@ class MWM_CB_UVEX5_Carton(BaseCarton):
         query = (GUVCat
                  .select(CatalogToTIC_v8.catalogid,
                          Gaia_DR2.source_id,
+                         Gaia_DR2.ra.alias('gaia_ra'),
+                         Gaia_DR2.dec.alias('gaia_dec'),
                          Gaia_DR2.pmra,
                          Gaia_DR2.pmdec,
                          Gaia_DR2.pmra_error,
@@ -739,6 +767,9 @@ class MWM_CB_UVEX5_Carton(BaseCarton):
                          Gaia_DR2.phot_rp_mean_mag,
                          BJ.r_est,
                          BJ.r_lo,
+                         GUVCat.objid.alias('guvcat_objid'),
+                         GUVCat.ra.alias('guvcat_ra'),
+                         GUVCat.dec.alias('guvcat_dec'),
                          GUVCat.nuv_mag,
                          GUVCat.fuv_mag,
                          GUVCat.nuv_magerr,
